@@ -14,10 +14,12 @@ private:
    CAceProtocol();
    int SearchAce(wxString &cmd);
    bool m_IsInstalled;
+   bool m_IsRunning;
 
 public:
    CAceProtocol(wxEvtHandler *parent, wxString url = "", wxString cmd = "");
    virtual ~CAceProtocol();
+   virtual void OnTerminate(int pid, int status);
    virtual int  StartProtocol(long &pid);
    virtual void StopProtocol();
    //virtual void OnTerminate(int pid, int status);
@@ -31,7 +33,10 @@ public:
       return m_IsInstalled;
    }
   
-   
+    bool IsRunning()
+   {
+      return m_IsRunning;
+   }
 
 };
 
