@@ -31,6 +31,10 @@ public:
    {
       return m_IsInstalled;
    };
+   int GetPid()
+   {
+      return m_protopid;
+   }
 };
 
 }
