@@ -4,6 +4,9 @@
 #include <wx/string.h>
 #include <wx/process.h>
 
+#define E_ERROR -1
+#define E_OK 0
+
 namespace tvlite
 {
 
