@@ -15,7 +15,7 @@ channelListCtrl::~channelListCtrl()
 
 wxString channelListCtrl::OnGetItemText (long item, long column) const
 {
-   if(item < m_channelList->Count())
+   if(item < (long)m_channelList->Count())
    {
       return (*m_channelList)[item]->GetName();
 
