@@ -572,9 +572,14 @@ void TytDlpConfiguration::Load()
 {
    wxString stringkey;
    bool boolkey;
-   if (!(TVLITECONFIG->Read(YTDLP_FULLPATH, &stringkey, "")))
+   wxString sytDlpExePath;
+#ifdef __WXMSW__
+    wxStandardPaths stdPath = wxStandardPaths::Get();
+    sytDlpExePath = stdPath.GetDataDir() + "\\yt-dlp.exe";
+#endif
+   if (!(TVLITECONFIG->Read(YTDLP_FULLPATH, &stringkey, sytDlpExePath)))
    {
-      DBG_INFO("yt-dlp path: Used default value (empty string)");
+      DBG_INFO("yt-dlp path: Used default value");
    }
    m_ytDlpPath = stringkey;
    
