@@ -166,14 +166,31 @@ int CDataBase::GetInfoTableData(CSubscriptionInfo *dataBaseInfo)
 }
 
 
-int CDataBase::GetNumberOfChannels()
+int CDataBase::GetNumberOfChannels( eTableType table)
 {
+   int rc = 0;
    char *errmsg;
-   wxString checkstmt = "SELECT count(*) FROM tv_channels;";
-   int rc = sqlite3_exec(m_db, (const char*)checkstmt.utf8_str(), number_callback, (void*)&m_number_of_channels, &errmsg);
-   if (rc)
+   wxString checkstmt;
+   switch(table)
    {
-      wxMessageBox("While retrieving channel number:\n " + wxString(errmsg,wxConvUTF8), "Error", wxOK | wxICON_STOP, NULL);
+      case E_TV_TABLE:
+         checkstmt = "SELECT count(*) FROM tv_channels;";
+         break;
+      case E_RADIO_TABLE:
+         checkstmt = "SELECT count(*) FROM radio_channels;";
+         break;
+      default:
+         rc = -1;
+         wxMessageBox(_("Invalid table specified"),"Error", wxOK | wxICON_STOP, NULL);
+         break;
+   }
+   if (0 == rc)
+   {
+      rc = sqlite3_exec(m_db, (const char*)checkstmt.utf8_str(), number_callback, (void*)&m_number_of_channels, &errmsg);
+      if (rc)
+      {
+         wxMessageBox("While retrieving channel number:\n " + wxString(errmsg,wxConvUTF8), "Error", wxOK | wxICON_STOP, NULL);
+      }
    }
    return rc;
 
@@ -223,25 +240,34 @@ int CDataBase::info_callback(void *data, int nr_cols, char **arg, char **colname
    return E_DB_OK;
 }
 
-int CDataBase::GetTVTableData(TChannelList *channelList)
+int CDataBase::GetTVTableData(TChannelList *channelList, eTableType table)
 {
    //DBG_INFO("Entering info table.");
 
    char *errmsg;
-   int rc = GetNumberOfChannels();
-   if (!rc)
+   wxString checkstmt;
+   int rc = GetNumberOfChannels(table);
+   if (0 == rc)
    {
-      wxString checkstmt = "SELECT * FROM tv_channels;";
-      int rc = sqlite3_exec(m_db, (const char*)checkstmt.utf8_str() ,channel_callback, (void*)channelList, &errmsg);
-      if (rc)
+      switch(table)
       {
-         wxMessageBox("While retrieving channels:\n " + wxString(errmsg,wxConvUTF8), "Error", wxOK | wxICON_STOP, NULL);
+       case E_TV_TABLE:
+         checkstmt = "SELECT * FROM tv_channels;";
+         break;
+      case E_RADIO_TABLE:
+         checkstmt = "SELECT * FROM radio_channels;";
+         break;
       }
-      //sqlite3_db_release_memory(m_db);
-      //int cur, high;
-      //sqlite3_status(SQLITE_STATUS_MEMORY_USED, &cur, &high, 0);
-      //wxMessageBox("DB Status:\n " + wxString::Format("current=%ld, max.%ld",cur, high), "Info", wxOK | wxICON_INFORMATION, NULL);
    }
+   rc = sqlite3_exec(m_db, (const char*)checkstmt.utf8_str() ,channel_callback, (void*)channelList, &errmsg);
+   if (rc)
+   {
+      wxMessageBox("While retrieving channels:\n " + wxString(errmsg,wxConvUTF8), "Error", wxOK | wxICON_STOP, NULL);
+   }
+   //sqlite3_db_release_memory(m_db);
+   //int cur, high;
+   //sqlite3_status(SQLITE_STATUS_MEMORY_USED, &cur, &high, 0);
+   //wxMessageBox("DB Status:\n " + wxString::Format("current=%ld, max.%ld",cur, high), "Info", wxOK | wxICON_INFORMATION, NULL);
    return rc;
 }
 
@@ -313,7 +339,7 @@ int CDataBase::channel_callback(void *data, int nr_cols, char **arg, char **coln
 }
 
 
-int CDataBase::SetTVTableData(TChannelList &channelList)
+int CDataBase::SetTVTableData(TChannelList &channelList, eTableType table)
 {
 
   int rc;
@@ -326,7 +352,7 @@ int CDataBase::SetTVTableData(TChannelList &channelList)
   }
   for (size_t i = 0; i < channelList.GetCount(); i++)
   {
-     rc = AddChannel(channelList[i]);
+     rc = AddChannel(channelList[i], table);
      if (rc) break;
   }
   if (!rc)
@@ -342,14 +368,15 @@ int CDataBase::SetTVTableData(TChannelList &channelList)
 }
 
 
-int CDataBase::AddChannel(CChannel &ch)
+int CDataBase::AddChannel(CChannel &ch, eTableType table)
 {
    //DBG_INFO("Storing channel.");
    wxString iconData = "iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAAJklEQVR4nO3NMQEAAA\
 jDMMC/52ECvlRA00nqs3m9AwAAAAAAAJy1C7oDLV5LB/0AAAAASUVORK5CYII=";
    wxString stmt;
    sqlite3_stmt *compiled_stmt; //placeholder
-
+   int rc = SQLITE_OK;
+   bool statement_prepared = false;
    if (ch.GetId() == "")
    {
          wxString id = ch.GetName().BeforeFirst(' ');
@@ -360,9 +387,23 @@ jDMMC/52ECvlRA00nqs3m9AwAAAAAAAJy1C7oDLV5LB/0AAAAASUVORK5CYII=";
    wxArrayString urls = ch.GetStreamURLs();
    //streamrecordtype params = ch.GetStreamParams();
    wxArrayString achs = ch.GetAudioChannels();
-
-   stmt = "INSERT INTO 'tv_channels' VALUES (@id, @iconData, @name, @streamurls, @params, @guide, @ach);";
-   int rc = sqlite3_prepare_v2(m_db, (const char*)stmt.utf8_str(), -1, &compiled_stmt, 0);
+    switch(table)
+      {
+       case E_TV_TABLE:
+         stmt = "INSERT INTO 'tv_channels' VALUES (@id, @iconData, @name, @streamurls, @params, @guide, @ach);";
+         break;
+      case E_RADIO_TABLE:
+         stmt = "INSERT INTO 'radio_channels' VALUES (@id, @iconData, @name, @streamurls, @params);";
+         break;
+      default:
+         rc = SQLITE_ABORT;
+         break;
+   }
+   if (rc == SQLITE_OK)
+   { 
+      rc = sqlite3_prepare_v2(m_db, (const char*)stmt.utf8_str(), -1, &compiled_stmt, 0);
+      statement_prepared = true;
+   }
    if (rc == SQLITE_OK)
    {
       int idx = sqlite3_bind_parameter_index(compiled_stmt, "@id");
@@ -403,20 +444,23 @@ jDMMC/52ECvlRA00nqs3m9AwAAAAAAAJy1C7oDLV5LB/0AAAAASUVORK5CYII=";
       const char* str = (const char*)stemp.utf8_str();
       rc = sqlite3_bind_text(compiled_stmt, idx, str, -1, SQLITE_TRANSIENT);
    }
-   if (rc == SQLITE_OK)
-   {
-      int idx = sqlite3_bind_parameter_index(compiled_stmt, "@guide");
-      wxString stemp = ch.GetId();
-      const char* str = (const char*)stemp.utf8_str();
-      rc = sqlite3_bind_text(compiled_stmt, idx, str, -1, SQLITE_TRANSIENT);
-   }
-   if (rc == SQLITE_OK)
-   {
-      int idx = sqlite3_bind_parameter_index(compiled_stmt, "@ach");
-      wxString stemp;
-      ch.ConvertToJSONArray(achs, stemp);
-      const char* str = (const char*)stemp.utf8_str();
-      rc = sqlite3_bind_text(compiled_stmt, idx, str, -1, SQLITE_TRANSIENT);
+   if (table == E_TV_TABLE)
+   {   
+      if (rc == SQLITE_OK)
+      {
+         int idx = sqlite3_bind_parameter_index(compiled_stmt, "@guide");
+         wxString stemp = ch.GetId();
+         const char* str = (const char*)stemp.utf8_str();
+         rc = sqlite3_bind_text(compiled_stmt, idx, str, -1, SQLITE_TRANSIENT);
+      }
+      if (rc == SQLITE_OK)
+      {
+         int idx = sqlite3_bind_parameter_index(compiled_stmt, "@ach");
+         wxString stemp;
+         ch.ConvertToJSONArray(achs, stemp);
+         const char* str = (const char*)stemp.utf8_str();
+         rc = sqlite3_bind_text(compiled_stmt, idx, str, -1, SQLITE_TRANSIENT);
+      }
    }
    if (rc == SQLITE_OK)
    {
@@ -426,25 +470,43 @@ jDMMC/52ECvlRA00nqs3m9AwAAAAAAAJy1C7oDLV5LB/0AAAAASUVORK5CYII=";
     if (rc != SQLITE_DONE) {
          wxMessageBox("While inserting channels:\n " + wxString(sqlite3_errmsg(m_db),wxConvUTF8), "Error", wxOK | wxICON_STOP, NULL);
     }
-
-    sqlite3_finalize(compiled_stmt);
+    
+    if (statement_prepared)
+    {
+      sqlite3_finalize(compiled_stmt);
+    }
     urls.Clear();
     achs.Clear();
 
    return (rc == SQLITE_DONE) ? SQLITE_OK : rc;
 }
 
-int CDataBase::UpdateChannel(CChannel &ch)
+int CDataBase::UpdateChannel(CChannel &ch, eTableType table)
 {
     DBG_INFO("Updating channel.");
     wxString stmt;
     sqlite3_stmt *compiled_stmt; //placeholder
+    bool statement_prepared = false;
+    int rc = SQLITE_OK; 
     wxArrayString urls = ch.GetStreamURLs();
     wxArrayString achs = ch.GetAudioChannels();
-
-    stmt = "UPDATE tv_channels SET name = @name WHERE id = @id; " ;
-
-    int rc = sqlite3_prepare_v2(m_db, (const char*)stmt.utf8_str(), -1, &compiled_stmt, 0);
+    switch(table)
+      {
+       case E_TV_TABLE:
+            stmt = "UPDATE tv_channels SET name = @name WHERE id = @id; " ;
+         break;
+         case E_RADIO_TABLE:
+            stmt = "UPDATE radio_channels SET name = @name WHERE id = @id; " ;
+         break;
+         default:
+            rc = SQLITE_ABORT;
+         break;
+      }    
+    if (rc == SQLITE_OK)
+    {
+      rc = sqlite3_prepare_v2(m_db, (const char*)stmt.utf8_str(), -1, &compiled_stmt, 0);
+      statement_prepared = true;
+    }
     if (rc == SQLITE_OK)
     {
       int idx = sqlite3_bind_parameter_index(compiled_stmt, "@id");
@@ -471,13 +533,30 @@ int CDataBase::UpdateChannel(CChannel &ch)
    {
       wxMessageBox("While inserting channels:\n " + wxString(sqlite3_errmsg(m_db),wxConvUTF8), "Error", wxOK | wxICON_STOP, NULL);
    }
-
-   sqlite3_finalize(compiled_stmt);
-
+   if (statement_prepared)
+   {
+      sqlite3_finalize(compiled_stmt);
+   }
+   statement_prepared = false;
    if (rc == SQLITE_DONE)
    {
-      stmt = "UPDATE tv_channels SET streamurls = @streamurls, params = @params WHERE id = @id;";
-      rc = sqlite3_prepare_v2(m_db, (const char*)stmt.utf8_str(), -1, &compiled_stmt, 0);
+      rc = SQLITE_OK;
+      switch(table)
+      {
+       case E_TV_TABLE:
+         stmt = "UPDATE tv_channels SET streamurls = @streamurls, params = @params WHERE id = @id;";
+       break;
+       case E_RADIO_TABLE:
+         stmt = "UPDATE radio_channels SET streamurls = @streamurls, params = @params WHERE id = @id;";
+       break;  
+       default:
+            rc = SQLITE_ABORT;
+       break;
+      }
+      if (rc == SQLITE_OK)
+      {
+         rc = sqlite3_prepare_v2(m_db, (const char*)stmt.utf8_str(), -1, &compiled_stmt, 0);
+      }
    }
    if (rc == SQLITE_OK)
    {
@@ -510,19 +589,36 @@ int CDataBase::UpdateChannel(CChannel &ch)
    {
       wxMessageBox("While updating channels:\n " + wxString(sqlite3_errmsg(m_db),wxConvUTF8), "Error", wxOK | wxICON_STOP, NULL);
    }
-
-   sqlite3_finalize(compiled_stmt);
+   if (statement_prepared)
+   {
+      sqlite3_finalize(compiled_stmt);
+   }
    return (rc == SQLITE_DONE) ? SQLITE_OK : rc;
 
 }
 
-int CDataBase::DeleteChannel(CChannel &ch)
+int CDataBase::DeleteChannel(CChannel &ch, eTableType table)
 {
    //DBG_INFO("Updating channel.");
+   int rc = SQLITE_OK;
    char *errmsg;
    wxString stmt;
-   stmt = "DELETE FROM tv_channels WHERE id = '" + ch.GetId() + "' ;";
-   int rc = sqlite3_exec(m_db, (const char*)stmt.utf8_str(), NULL, NULL, &errmsg);
+   switch(table)
+   {
+      case E_TV_TABLE:
+         stmt = "DELETE FROM tv_channels WHERE id = '" + ch.GetId() + "' ;";
+         break;
+      case E_RADIO_TABLE:
+         stmt = "DELETE FROM radio_channels WHERE id = '" + ch.GetId() + "' ;";
+         break;
+      default:
+         rc = SQLITE_ABORT;
+         break;
+   }
+   if (rc == SQLITE_OK)
+   {
+      rc = sqlite3_exec(m_db, (const char*)stmt.utf8_str(), NULL, NULL, &errmsg);
+   }
    if (rc)
    {
       wxMessageBox("While deleting channels:\n " + wxString(errmsg,wxConvUTF8), "Error", wxOK | wxICON_STOP, NULL);
@@ -540,6 +636,15 @@ int CDataBase::ResetTVTableData()
    return rc;
 }
 
+int CDataBase::ResetRadioTableData()
+{
+   int rc = DeleteTable("radio_channels");
+   if (!rc)
+   {
+      rc = InitRadioTable();
+   }
+   return rc;
+}
 
 int CDataBase::SetInfoTableData(CSubscriptionInfo &dataBaseInfo)
 {
