@@ -28,7 +28,8 @@ private:
    wxTimer m_timer;
    size_t downloadIndex;
    bool m_canClose;
-   TChannelList *chanlist;
+   TChannelList *tvchanlist;
+   TChannelList *radiochanlist;
 
 public:
    CDLProgress() = delete;
