@@ -18,12 +18,12 @@ private:
 public:
    CLocalList();
    CLocalList(wxString uri);
-   int ReadData(TChannelList *list); //new function
+   int ReadData(TChannelList *tvChannelList, TChannelList *radioChannelList); //new function
    virtual ~CLocalList();
    static void GetStoredData(TLocalLists &subList);
-   int AddChannel(CChannel channel);
-   int UpdateChannel(CChannel channel);
-   int DeleteChannel(CChannel channel);
+   int AddChannel(CChannel channel, eTableType table = E_TV_TABLE);
+   int UpdateChannel(CChannel channel, eTableType table = E_TV_TABLE);
+   int DeleteChannel(CChannel channel, eTableType table = E_TV_TABLE);
    int UpdateInfo(CSubscriptionInfo &info);
     static int Compare( CLocalList **item1, CLocalList **item2);
 protected:
