@@ -29,11 +29,14 @@ class CPrefDialog : public CPrefDialogBase
    virtual void OnHwAccType( wxCommandEvent& event ); 
 	virtual void OnAcestreamExecPathClick( wxCommandEvent& event );
 	virtual void OnOkClicked( wxCommandEvent& event );
-   virtual void OnProxyUseClick(wxCommandEvent& event);
-   virtual void OnProxyAuthCheck(wxCommandEvent& event);
+   virtual void OnProxyUseClick( wxCommandEvent& event );
+   virtual void OnProxyAuthCheck( wxCommandEvent& event );
+   virtual void OnYTDlpPathClick( wxCommandEvent& event );
+   virtual void OnYTDlpUseCheck( wxCommandEvent& event );
    private:
    void CheckProxyUsage(bool state);
    void CheckAuthUsage (bool state);
+   void CheckYTDlpUsage(bool state);
 };
 
 }
