@@ -24,8 +24,9 @@ using namespace tvlite;
 
 CSubscription::CSubscription()
 {
-  m_chanlist   = NULL;
-  m_evtHandler = NULL;
+  m_tvchanlist   = nullptr;
+  m_radiochanlist = nullptr;
+  m_evtHandler = nullptr;
 }
 
 
@@ -52,9 +53,10 @@ void CSubscription::SetEventHandler(wxEvtHandler* evtHandler)
    m_evtHandler = evtHandler;
 }
 
-void CSubscription::SetChannelList(TChannelList *chanlist)
+void CSubscription::SetChannelList(TChannelList *tvchanlist, TChannelList *radiochanlist)
 {
-   m_chanlist = chanlist;
+   m_tvchanlist = tvchanlist;
+   m_radiochanlist = radiochanlist;
 }
 
 CSubscriptionInfo* CSubscription::GetSubscriptionInfo()
@@ -82,10 +84,11 @@ CDownloadClient* CSubscription::GetDLClient()
    return m_dlClient;
 }
 
-int CSubscription::ReadData(TChannelList *channelList)
+int CSubscription::ReadData(TChannelList *tvChannelList, TChannelList *radioChannelList)
 {
    int rc = E_SUB_OK;
-   m_chanlist = channelList;
+   m_tvchanlist = tvChannelList;
+   m_radiochanlist = radioChannelList;
    wxURI uri;
    DBG_INFO("[DEBUG] m_uri is %s", (const char*)m_uri.utf8_str());
    if (!uri.Create(m_uri))
@@ -128,7 +131,7 @@ int CSubscription::ReadData(TChannelList *channelList)
             wxQueueEvent(m_evtHandler, dtreadNotifyEvent.Clone());
          }
          wxString unescapedURI = uri.BuildUnescapedURI();
-         rc = CacheNewData(m_chanlist, unescapedURI);
+         rc = CacheNewData(m_tvchanlist, m_radiochanlist, unescapedURI);
          if (m_evtHandler)
          {
             wxCommandEvent dtreadNotifyEvent(DTPARSEDNOTIFY_EVT);
@@ -155,7 +158,7 @@ void CSubscription::OnReadDataResponse (wxThreadEvent &event)
    if (event.GetInt() == 0)
    {
       DBG_ERROR("CSubscription: Download OK");
-      rc = CacheNewData(m_chanlist, m_importFile);
+      rc = CacheNewData(m_tvchanlist, m_radiochanlist, m_importFile);
    }
    else
    {
@@ -174,12 +177,13 @@ void CSubscription::OnReadDataResponse (wxThreadEvent &event)
 
 }
 
-int CSubscription::CacheNewData(TChannelList *channelList, wxString importfile)
+int CSubscription::CacheNewData(TChannelList *tvChannelList, TChannelList *radioChannelList, wxString importfile)
 {
    int rc = E_SUB_OK;
    wxString newCachedFile;
-   channelList->Clear();
-   rc = ReadDataFromFile(channelList, importfile );
+   tvChannelList->Clear();
+   radioChannelList->Clear();
+   rc = ReadDataFromFile(tvChannelList, radioChannelList, importfile);
    if (rc == E_SUB_OK)
    {
       m_cachedFile = FindCachedData(m_uri);
@@ -199,7 +203,7 @@ int CSubscription::CacheNewData(TChannelList *channelList, wxString importfile)
 }
 
 
-int CSubscription::ReadDataFromCache(TChannelList *channelList)
+int CSubscription::ReadDataFromCache(TChannelList *tvchannelList, TChannelList *radiochannelList)
 {
    wxString readuri;
    wxString importfile;
@@ -208,7 +212,8 @@ int CSubscription::ReadDataFromCache(TChannelList *channelList)
    DBG_INFO("[DEBUG] m_uri is %s", (const char*)m_uri.utf8_str());
    readuri = FindCachedData(m_subscriptionInfo.url);
    DBG_INFO("Reading from cache");
-   channelList->Clear();
+   tvchannelList->Clear();
+   radiochannelList->Clear();
    if (readuri == "")
    {
       DBG_ERROR("Data file not found in cache!");
@@ -217,7 +222,7 @@ int CSubscription::ReadDataFromCache(TChannelList *channelList)
 
    if (rc == E_SUB_OK)
    {
-       rc = ReadDataFromFile(channelList, readuri);
+       rc = ReadDataFromFile(tvchannelList, radiochannelList, readuri);
    }
    else
    {
@@ -227,13 +232,23 @@ int CSubscription::ReadDataFromCache(TChannelList *channelList)
    return rc;
 }
 
-int CSubscription::ReadDataFromFile(TChannelList *channelList, wxString importfile)
+int CSubscription::ReadDataFromFile(TChannelList *tvChannelList, TChannelList *radioChannelList, wxString importfile)
 {
       DBG_INFO("Parse from %s",(const char*)importfile.utf8_str());
-      channelList->Clear();
+      
+      int rc = -1;
       wxString announceParse = _("Parsing playlist");
       CStatusGauge::ShowStatusGauge(E_SB_LISTPROGRESS, announceParse);
-      int rc = ParseData(channelList, importfile);
+      if (nullptr != tvChannelList)
+      {
+         tvChannelList->Clear();
+         rc = ParseData(tvChannelList, importfile, E_TV_TABLE);
+      }
+      if (nullptr != radioChannelList)
+      {    
+         radioChannelList->Clear();
+         rc = ParseData(radioChannelList, importfile, E_RADIO_TABLE);
+      }
       CStatusGauge::HideStatusGauge(E_SB_LISTPROGRESS);
       return rc;
 }
@@ -249,7 +264,7 @@ bool CSubscription::TestM3U(const char* testbuffer)
 
 }
 
-int CSubscription::ParseData(TChannelList *channelList, wxString dbFile)
+int CSubscription::ParseData(TChannelList *channelList, wxString dbFile, eTableType table)
 {
    const unsigned int someLength = 1024;
    const unsigned int minLength  = 16;
@@ -273,11 +288,15 @@ int CSubscription::ParseData(TChannelList *channelList, wxString dbFile)
 
    if (!strncmp((const char*)buffer,"SQLite", strlen("SQLite")))
    {
-      return ParseDbData(channelList, dbFile);
+      return ParseDbData(channelList, dbFile, table);
    }
    else if (TestM3U((const char *)buffer))
    {
-      if (ParseM3UData(channelList, dbFile, wxConvUTF8))
+      if (table != E_TV_TABLE)
+      {
+         DBG_INFO("M3U file does not have radio data, Not parsing");
+      }
+      else if (ParseM3UData(channelList, dbFile, wxConvUTF8))
       {
          wxMBConv *conv = new wxConvAuto();
          if (ParseM3UData(channelList, dbFile, *conv))
@@ -311,7 +330,7 @@ int CSubscription::GetDBInfo(wxString dbFile, CSubscriptionInfo* rh)
    return rc;
 }
 
-int CSubscription::ParseDbData(TChannelList *channelList, wxString dbFile)
+int CSubscription::ParseDbData(TChannelList *channelList, wxString dbFile, eTableType table)
 {
    DBG_INFO("Parsing db data");
    CDataBase db(dbFile);
@@ -335,7 +354,7 @@ int CSubscription::ParseDbData(TChannelList *channelList, wxString dbFile)
    }
    if (rc == E_DB_OK)
    {
-      rc = db.GetTVTableData(channelList);
+      rc = db.GetTVTableData(channelList, table);
    }
    return 0;
 }
@@ -566,9 +585,13 @@ int  CSubscription::SaveData(wxString path, bool keepuri /* = false */)
     }
     if (rc == E_DB_OK)
     {
-       if (m_chanlist != NULL)
+       if (m_tvchanlist != NULL)
        {
-         rc = subDb.SetTVTableData(*m_chanlist);
+         rc = subDb.SetTVTableData(*m_tvchanlist, E_TV_TABLE);
+       }
+       if (m_radiochanlist != NULL)
+       {
+         rc = subDb.SetTVTableData(*m_radiochanlist, E_RADIO_TABLE);
        }
     }
     CStatusGauge::HideStatusGauge(E_SB_LISTPROGRESS);
@@ -631,17 +654,28 @@ wxString CSubscription::FindCachedData(wxString url)
    return rcString;
 }
 
-unsigned int CSubscription::GetNumberOfChannels()
+unsigned int CSubscription::GetNumberOfChannels(eTableType table)
 {
-   return m_chanlist->GetCount();
+   unsigned int nr = 0;
+   switch(table)
+   {
+      case E_TV_TABLE:
+         nr = m_tvchanlist->GetCount();
+         break;
+      case E_RADIO_TABLE:
+         nr = m_radiochanlist->GetCount();
+         break;
+   }
+   return nr;
 }
 
-unsigned int CSubscription::GetNumberOfSources()
+unsigned int CSubscription::GetNumberOfSources(eTableType table)
 {
    unsigned int sources = 0;
-   for (size_t i = 0; i < m_chanlist->GetCount(); i++)
+   TChannelList *chanlist = table == E_TV_TABLE ? m_tvchanlist : m_radiochanlist; 
+   for (size_t i = 0; i < chanlist->GetCount(); i++)
    {
-      wxArrayString s = m_chanlist->Item(i).GetStreamURLs();
+      wxArrayString s = chanlist->Item(i).GetStreamURLs();
       sources += s.GetCount();
       s.Clear();
    }
