@@ -1,3 +1,4 @@
+#include <unistd.h>
 #include "vlcplayer.h"
 #include <wx/window.h>
 #include <wx/stdpaths.h>
@@ -9,6 +10,7 @@
 #include "userdataobject.h"
 #include "proxy.h"
 #include "main.h"
+#include "ytprotocol.h"
 
 using namespace tvlite;
 
@@ -124,9 +126,18 @@ void CVlcPlayer::Play(ELocationType type, int fd, wxArrayString options)
       m_fileDescriptor = fd;
       Play(type, wxString(""), options);
 }
+
+void CVlcPlayer::Play(ELocationType type, wxProcess *process, wxArrayString options)
+{
+      m_streamInfo.process = process;
+      m_streamInfo.stop = false;
+      Play(type, wxString(""), options);
+}
+
 void CVlcPlayer::Play(ELocationType type, wxString location, wxArrayString options)
 {
         DBG_INFO("Entering Play");
+        m_type = type;
         m_wasStopped = false;
         if (type == elURI && location == "")
         {
@@ -205,7 +216,11 @@ void CVlcPlayer::Play(ELocationType type, wxString location, wxArrayString optio
         {
            if (m_fileDescriptor != -1)
            media = libvlc_media_new_fd(m_vlc_inst, m_fileDescriptor);
-        }  
+        }
+        else if (type == elCallback)
+        {
+            media = libvlc_media_new_callbacks(m_vlc_inst,  NULL, streamRead, streamSeek, streamClose, (void*)this);
+        }
         else
         {
            //invalid location -> media will be invalid
@@ -250,10 +265,18 @@ void CVlcPlayer::Play()
 
 void CVlcPlayer::Stop()
 {
-       m_wasStopped = true;
-       libvlc_media_player_pause(m_media_player);
-       libvlc_media_player_stop (m_media_player);
-       ResetTracks();
+       if (!m_wasStopped)
+       {
+          DBG_INFO("Stopping VLC Player...") ;
+          m_wasStopped = true;     
+          libvlc_media_player_pause(m_media_player);
+          libvlc_media_player_stop (m_media_player);
+          ResetTracks();
+       }
+       else 
+       {
+          DBG_INFO("Stopping VLC Player: player already stopped!") ;
+       }
 }
 
 void CVlcPlayer::VlcEvtCallback(const struct libvlc_event_t *p_event, void *p_data)
@@ -277,6 +300,10 @@ void CVlcPlayer::VlcEvtCallback(const struct libvlc_event_t *p_event, void *p_da
 //         DBG_INFO("Number of video outputs = %d", libvlc_media_player_has_vout(static_cast<CVlcPlayer *>(p_data)->m_media_player));
 
        }
+       if (p_event->type == libvlc_MediaPlayerStopped)
+       {
+         static_cast<CVlcPlayer *>(p_data)->SetStopped(true);
+       }
 }
 
 void CVlcPlayer::SetVolume(int value)
@@ -314,6 +341,10 @@ bool CVlcPlayer::WasStopped()
 {
    return m_wasStopped;
 }
+void CVlcPlayer::SetStopped(bool stopped)
+{
+   m_wasStopped = stopped;
+}
 
 void CVlcPlayer::Pause()
 {
@@ -367,6 +398,7 @@ WX_DEFINE_OBJARRAY(TTrackInfoList);
 
 int CVlcPlayer::GetTracks(TTrackInfoList &tracklist, ETrackType trackType)
 {
+   //m_vlcMutex.Lock();
    libvlc_track_description_t *p_tracks;
    switch (trackType)
    {
@@ -383,6 +415,7 @@ int CVlcPlayer::GetTracks(TTrackInfoList &tracklist, ETrackType trackType)
       return -1;
       break;
    }
+   //m_vlcMutex.Unlock();
    libvlc_track_description_t * iter = p_tracks;
    while (iter)
    {
@@ -398,13 +431,14 @@ int CVlcPlayer::GetTracks(TTrackInfoList &tracklist, ETrackType trackType)
         tracklist.Add(crt_track);
         iter = iter->p_next;
    }
-   for (size_t i = 0;  i < tracklist.Count(); i++)
-   {
-       DBG_INFO("track %ld, index = %d, type = %d, info = %s", i,
-               tracklist[i].GetIndex(),
-               tracklist[i].GetType(),
-               (const char*)tracklist[i].GetInfo().utf8_str());
-   }
+   
+//   for (size_t i = 0;  i < tracklist.Count(); i++)
+//   {
+//       DBG_INFO("track %zu, index = %d, type = %d, info = %s", i,
+//               tracklist[i].GetIndex(),
+//               tracklist[i].GetType(),
+//               (const char*)tracklist[i].GetInfo().utf8_str());
+//   }
    libvlc_track_description_list_release(p_tracks);
    return 0;
 }
@@ -519,7 +553,7 @@ wxString CVlcPlayer::GetUserAgent()
    wxString userAgent;
    int major, minor;
    int build = 0;
-#if (wxMAJOR_VERSION == 3 && wxMINOR_VERSION == 2)    
+#if (wxMAJOR_VERSION >= 3 && wxMINOR_VERSION >= 2)    
    wxOperatingSystemId OSId = wxGetOsVersion(&major, &minor, &build);
 #else
    wxOperatingSystemId OSId = wxGetOsVersion(&major, &minor);
@@ -565,7 +599,7 @@ wxString CVlcPlayer::GetUserAgent()
             {
                 infoStr = "Windows";
             }
-#if (wxMAJOR_VERSION == 3 && wxMINOR_VERSION == 2)  
+#if (wxMAJOR_VERSION >= 3 && wxMINOR_VERSION >= 2)  
             arch = wxGetCpuArchitectureName();
 #else
             if (wxIsPlatform64Bit())
@@ -584,7 +618,7 @@ wxString CVlcPlayer::GetUserAgent()
             break;
         case wxOS_UNIX_LINUX:
             infoStr = "Linux";
-#if (wxMAJOR_VERSION == 3 && wxMINOR_VERSION == 2)
+#if (wxMAJOR_VERSION >= 3 && wxMINOR_VERSION >= 2)
             arch = wxGetCpuArchitectureName();
 #else
             if (wxIsPlatform64Bit())
@@ -613,13 +647,16 @@ wxString CVlcPlayer::GetUserAgent()
 void CVlcPlayer::GetMeta(wxString &sArtist, wxString &sTitle)
 {
    if (m_wasStopped) return;
+   //m_mediaMutex.Lock();
    libvlc_media_t *p_media = libvlc_media_player_get_media(m_media_player);
    DBG_INFO("GetMeta called");
    sArtist = ""; sTitle = "";
    if (p_media != NULL)
    {
+      
       char *title  = libvlc_media_get_meta(p_media, libvlc_meta_Title);
       char *artist = libvlc_media_get_meta(p_media, libvlc_meta_NowPlaying);
+      
       if (title != NULL)
       {
          sTitle = wxString(title, wxConvUTF8);
@@ -635,6 +672,7 @@ void CVlcPlayer::GetMeta(wxString &sArtist, wxString &sTitle)
    {
       DBG_INFO("NULL media found");
    }
+   //m_mediaMutex.Unlock();
 }
 
 
@@ -712,3 +750,118 @@ void CVlcPlayer::DialogCancel(void *p_data, libvlc_dialog_id *p_id)
    libvlc_dialog_dismiss(p_id);
 }
 
+
+int CVlcPlayer::streamSeek(void *opaque, uint64_t offset)
+{
+    int rv = 0;
+    CYTProtocol* process;
+    process = (CYTProtocol*)((CVlcPlayer*)opaque)->GetProcess();
+    wxInputStream* inputStream = process->GetInputStream();
+    bool stopped = ((CVlcPlayer*)opaque)->GetInputStreamStopped();
+
+        if (stopped)
+        {
+             rv = -1;
+        }
+        else
+        {  
+           if (inputStream->SeekI(offset, wxFromCurrent) == wxInvalidOffset)
+               rv = -1;
+        }
+        return rv;
+}
+
+ssize_t CVlcPlayer::streamRead(void *opaque, unsigned char *buf, size_t len)
+{
+    CYTProtocol* process = nullptr;
+    size_t nrbytes = 0;
+    wxInputStream* inputStream = nullptr;
+    process = (CYTProtocol*)((CVlcPlayer*)opaque)->GetProcess();
+    if (process != nullptr)
+    {
+        inputStream = process->GetInputStream();
+    }
+    if (buf != nullptr && opaque != nullptr && inputStream != nullptr)
+    {
+        
+        nrbytes = 0;
+        do 
+        {  
+            nrbytes = 0;
+            if (((CVlcPlayer*)opaque)->GetInputStreamStopped())
+            {
+                nrbytes = -1;
+            }
+            else if (process->IsInputAvailable())
+            {
+                nrbytes = inputStream->Read((char *)buf, len).LastRead();
+
+                if (nrbytes == 0)
+                {    
+                    bool eof = inputStream->Eof();
+                    if (eof)
+                    {
+                        nrbytes = -1;
+                    }
+                }
+            }
+            else
+            {
+                //do nothing 
+            }
+            if (nrbytes == 0)
+            {
+                sleep(0);
+            }
+        }
+        while (nrbytes == 0);
+        return (ssize_t)nrbytes;
+    }
+    else
+    {   
+        return (ssize_t)-1;
+    }
+}  
+
+void CVlcPlayer::streamClose(void *opaque)
+{
+
+}
+
+void CVlcPlayer::SetProcess(wxProcess *process)
+{
+    m_vlcMutex.Lock();
+    m_streamInfo.process = process;
+    m_vlcMutex.Unlock();
+    
+}
+
+wxProcess* CVlcPlayer::GetProcess()
+{
+    m_vlcMutex.Lock();
+    wxProcess *process = m_streamInfo.process;
+    m_vlcMutex.Unlock();
+    return process;
+}
+
+void CVlcPlayer::SetInputStreamStopped(bool stopped)
+{
+    m_vlcMutex.Lock();
+    m_streamInfo.stop = stopped;
+    m_vlcMutex.Unlock();
+    
+}
+
+bool CVlcPlayer::GetInputStreamStopped()
+{
+    bool stop;
+    m_vlcMutex.Lock();
+    stop = m_streamInfo.stop ;
+    m_vlcMutex.Unlock();
+    return stop;
+}
+
+ELocationType CVlcPlayer::GetType()
+{
+    return m_type;
+}
\ No newline at end of file
