@@ -13,6 +13,7 @@
 #include <wx/timer.h>
 #include <vlc/vlc.h>
 #include <wx/arrstr.h>
+#include <wx/stream.h>
 #include "vlcquestiondialog.h"
 
 wxDECLARE_EVENT(playerEVT, wxCommandEvent);
@@ -41,10 +42,15 @@ enum ELocationType
 {
    elFileDescriptor = 0,
    elURI,
+   elCallback,
    elInvalid
 };
 
-
+struct SStreamInfo
+{
+  wxProcess *process;
+  bool stop;   
+};
 class CTrackInfo
 {
    private:
@@ -95,9 +101,14 @@ private:
    int m_volume;
    ELocationType m_locationType;
    int m_fileDescriptor;
+
+   SStreamInfo m_streamInfo;
    libvlc_dialog_cbs m_dialogCallbacks;
    void *m_cb_data;
+   void *m_mediacbdata;
    CVLCQuestionDialog *m_questionDlg;
+   ELocationType m_type;
+   
     
 protected:
    wxEvtHandler *m_pparent;
@@ -106,8 +117,15 @@ protected:
                                libvlc_dialog_question_type i_type,
                                const char *psz_cancel, const char *psz_action1, const char *psz_action2);
    static void DialogCancel(void *p_data, libvlc_dialog_id *p_id);
-   static void DisplayError (void *p_data, const char *psz_title, const char *psz_text);            
+   static void DisplayError (void *p_data, const char *psz_title, const char *psz_text);
+   static ssize_t streamRead(void *opaque, unsigned char *buf, size_t len);
+   static int streamSeek(void *opaque, uint64_t offset);
+   static void streamClose(void *opaque);
+   
+        
 public:
+   wxMutex m_vlcMutex;
+   wxMutex m_mediaMutex;
    CVlcPlayer() = delete;
    CVlcPlayer(wxEvtHandler *parent);
    ~CVlcPlayer();
@@ -116,6 +134,7 @@ public:
    void SetFull();
    void Play(ELocationType type, wxString location, wxArrayString options);
    void Play(ELocationType type, int fd, wxArrayString options);
+   void Play(ELocationType type, wxProcess *process, wxArrayString options);
    void Play();
    void Stop();
    void Pause();
@@ -126,6 +145,7 @@ public:
    void SetAspectRatio(wxString aspectRatio);
    wxString GetAspectRatio();
    bool WasStopped();
+   void SetStopped(bool stopped);
    void SetRecordState(EVLCRecordState state);
    void SetRecordFileName(wxString name);
    void SetStreamPort(unsigned int port);
@@ -145,6 +165,13 @@ public:
    bool IsValidTime();
   
    void QuestionDlgShow (std::shared_ptr<SDlgData> data);
+   wxProcess *GetProcess();
+   void SetProcess( wxProcess *process);
+   void SetInputStreamStopped(bool stopped);
+   bool GetInputStreamStopped();
+   ELocationType GetType();
+   
+
 };
 }
 
