@@ -1,8 +1,14 @@
 #ifndef CYTPROTOCOL_H
 #define CYTPROTOCOL_H
+#include <wx/thread.h>
 #include "baseprotocol.h"
 
 
+#ifdef __WXGTK__
+   #define __APPL_USE_FILESTREAM__
+#endif 
+
+#define CIRC_BUFFER_SIZE 33554432L
 namespace tvlite
 {
 class CYTThread;
@@ -14,8 +20,11 @@ private:
    CYTProtocol& operator=(const CYTProtocol&) = delete;
    CYTProtocol(CYTProtocol&&) = delete;
    CYTProtocol& operator=(CYTProtocol&&) = delete;
+   wxInputStream *m_inputStream;
    int m_fileDescriptor;
+   wxOutputStream *m_outputStream;
    CYTThread *m_ytthread;
+   wxMutex m_accessMutex;
 
 public:
    CYTProtocol(wxEvtHandler *parent, wxString url, wxString cmd ="");
@@ -25,7 +34,6 @@ public:
 
    virtual int LoadConfig();
    virtual int SaveConfig();
-
    wxString GetUrl();
    void SetURL(wxString url);
 
@@ -34,7 +42,8 @@ public:
    int GetFileDescriptor();
    virtual void OnTerminate(int pid, int status);
    void WaitThread();
-
+   void LockAccessMutex();
+   void UnlockAccessMutex();
 };
 
 }
